package Math;

use strict;
use warnings;
use Wasm -api => 0, -self;

1;
